==> moru_payment_gateway-0.0.1.tar.gz: lib/widget/moru_payment_card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:moru_payment_gateway/dto/request/pay_data.dart';
import 'package:moru_payment_gateway/dto/request/user_validate.dart';
import 'package:moru_payment_gateway/dto/response/validated_access_res.dart';
import 'package:moru_payment_gateway/dto/response/validated_user_res.dart';
import 'package:moru_payment_gateway/presentation/bloc/pay/initiate_pay_cubit.dart';
import 'package:moru_payment_gateway/presentation/bloc/user_validator/user_validator_cubit.dart';

class MoRuPaymentCard extends StatefulWidget {
  final ValueChanged<String?> onPressed;

  final ValidatedAccessRes validatedAccessRes;
  final String accessKey;

  const MoRuPaymentCard(
      {Key? key,
      required this.onPressed,
      required this.validatedAccessRes,
      required this.accessKey})
      : super(key: key);

  @override
  _MoRuPaymentCardState createState() => _MoRuPaymentCardState();
}

class _MoRuPaymentCardState extends State<MoRuPaymentCard> {
  late final TextEditingController _pinController;
  late final TextEditingController _mobileController;
  late final ValueChanged<String?> _onPressed;
  bool hasInvalidPin = false;
  late final UserValidatorCubit _userValidatorCubit;
  late final InitiatePayCubit _initiatePayCubit;

  String? invalidRequestMessage;
  ValidatedUserRes? _validatedUserRes;

  @override
  void initState() {
    super.initState();
    _onPressed = widget.onPressed;
    _pinController = TextEditingController();
    _mobileController = TextEditingController();
    _userValidatorCubit = UserValidatorCubit();
  }

  @override
  void dispose() {
    super.dispose();
    _mobileController.dispose();
    _pinController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MultiBlocListener(
      listeners: [
        BlocListener<UserValidatorCubit, UserValidatorState>(
            listener: (context, state) {
          if (state is UserValidatorSuccess) {
            _validatedUserRes = state.validatedUserRes;

            if (_validatedUserRes != null &&
                _validatedUserRes!.data!.moruTxnIdentifier != null) {
              _initiatePayCubit.initiatePay(
                  payData: PayData(
                      accessKey: widget.accessKey,
                      txnRequestId: _validatedUserRes!.data!.moruTxnIdentifier!,
                      otp: _validatedUserRes!.data!.otp!));
            }
          } else if (state is UserValidatorFail) {
            setState(() {
              invalidRequestMessage = state.failedReason;
            });
          }
        }),
        BlocListener<InitiatePayCubit, InitiatePayState>(
            listener: (context, state) {
          if (state is PaySuccess) {
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text("Success"),
              ),
            );
          } else if (state is PayFail) {
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text("Fail"),
              ),
            );
          }
        }),
      ],
      child: Scaffold(
        body: Container(
          height: MediaQuery.of(context).size.height * 0.6,
          child: Column(
            children: [
              Container(
                child: Text("Amount: 200"),
              ),
              TextFormField(
                  controller: _mobileController,
                  decoration: InputDecoration(
                      errorText: invalidRequestMessage,
                      border: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: BorderSide(
                          width: 0.1,
                          color: Colors.transparent,
                          style: BorderStyle.solid,
                        ),
                      ),
                      contentPadding: EdgeInsets.all(8.0),
                      labelText: 'Mobile',
                      hintText: 'Enter your Moru Registered Mobile',
                      suffixIcon: Icon(Icons.arrow_drop_down))),
              Visibility(
                visible: _validatedUserRes != null
                    ? _validatedUserRes!.data!.otp != null
                    : false,
                child: TextFormField(
                    controller: _pinController,
                    decoration: InputDecoration(
                        errorText: hasInvalidPin ? 'Invalid  Pin' : null,
                        border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(8),
                          borderSide: BorderSide(
                            width: 0.1,
                            color: Colors.transparent,
                            style: BorderStyle.solid,
                          ),
                        ),
                        contentPadding: EdgeInsets.all(8.0),
                        labelText: 'Pin',
                        hintText: 'Enter your moru pin',
                        suffixIcon: Icon(Icons.arrow_drop_down))),
              ),
              Visibility(
                visible: widget.validatedAccessRes.data != null,
                child: MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: 40,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 55,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () {
                    _userValidatorCubit.validateUser(
                        userValidate: UserValidate(
                            accessKey: widget.accessKey,
                            txnRequestId: widget
                                .validatedAccessRes.data!.moruTxnIdentifier!,
                            pin: _pinController.text,
                            mobileNo: _mobileController.text));
                    if (_validatedUserRes != null) {
                      _initiatePayCubit.initiatePay(
                          payData: PayData(
                              accessKey: widget.accessKey,
                              txnRequestId:
                                  _validatedUserRes!.data!.moruTxnIdentifier!,
                              otp: _validatedUserRes!.data!.otp!));
                    }
                  },
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "Continue",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
              ),
              Visibility(
                visible: widget.validatedAccessRes.data != null,
                child: MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: 40,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 55,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () {},
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "Pay",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> moru_payment_gateway-0.0.3.tar.gz: lib/widget/moru_payment_card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:moru_payment_gateway/dto/request/pay_data.dart';
import 'package:moru_payment_gateway/dto/request/user_validate.dart';
import 'package:moru_payment_gateway/dto/response/validated_access_res.dart';
import 'package:moru_payment_gateway/dto/response/validated_user_res.dart';
import 'package:moru_payment_gateway/presentation/bloc/pay/initiate_pay_cubit.dart';
import 'package:moru_payment_gateway/presentation/bloc/user_validator/user_validator_cubit.dart';

class MoRuPaymentCard extends StatefulWidget {
  final ValueChanged<String?> onPressed;

  final ValidatedAccessRes validatedAccessRes;
  final String accessKey;

  const MoRuPaymentCard(
      {Key? key,
      required this.onPressed,
      required this.validatedAccessRes,
      required this.accessKey})
      : super(key: key);

  @override
  _MoRuPaymentCardState createState() => _MoRuPaymentCardState();
}

class _MoRuPaymentCardState extends State<MoRuPaymentCard> {
  late final TextEditingController _pinController;
  late final TextEditingController _otpController;
  late final TextEditingController _mobileController;
  late final ValueChanged<String?> _onPressed;
  bool hasInvalidPin = false;
  late final UserValidatorCubit _userValidatorCubit;
  late final InitiatePayCubit _initiatePayCubit;

  String? invalidRequestMessage;
  ValidatedUserRes? _validatedUserRes;
  bool isUserValidated = false;

  @override
  void initState() {
    super.initState();
    _onPressed = widget.onPressed;
    _pinController = TextEditingController();
    _mobileController = TextEditingController();
    _userValidatorCubit = UserValidatorCubit();
  }

  @override
  void dispose() {
    super.dispose();
    _mobileController.dispose();
    _pinController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MultiBlocListener(
      listeners: [
        BlocListener<UserValidatorCubit, UserValidatorState>(
            listener: (context, state) {
          if (state is UserValidatorSuccess) {
            _validatedUserRes = state.validatedUserRes;

            if (_validatedUserRes != null &&
                _validatedUserRes!.data!.moruTxnIdentifier != null) {
              setState(() {
                isUserValidated = true;
              });
            }
          } else if (state is UserValidatorFail) {
            setState(() {
              invalidRequestMessage = state.failedReason;
            });
          }
        }),
        BlocListener<InitiatePayCubit, InitiatePayState>(
            listener: (context, state) {
          if (state is PaySuccess) {
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text("Success"),
              ),
            );
          } else if (state is PayFail) {
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text("Fail"),
              ),
            );
          }
        }),
      ],
      child: Scaffold(
        body: Container(
          height: MediaQuery.of(context).size.height * 0.6,
          child: Column(
            children: [
              Container(
                child: Text("Amount: 200"),
              ),
              Visibility(
                visible: !isUserValidated,
                child: TextFormField(
                    controller: _mobileController,
                    decoration: InputDecoration(
                        errorText: invalidRequestMessage,
                        border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(8),
                          borderSide: BorderSide(
                            width: 0.1,
                            color: Colors.transparent,
                            style: BorderStyle.solid,
                          ),
                        ),
                        contentPadding: EdgeInsets.all(8.0),
                        labelText: 'Mobile',
                        hintText: 'Enter your Moru Registered Mobile',
                        suffixIcon: Icon(Icons.arrow_drop_down))),
              ),
              Visibility(
                visible: !isUserValidated,
                child: TextFormField(
                    controller: _pinController,
                    decoration: InputDecoration(
                        errorText: hasInvalidPin ? 'Invalid  Pin' : null,
                        border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(8),
                          borderSide: BorderSide(
                            width: 0.1,
                            color: Colors.transparent,
                            style: BorderStyle.solid,
                          ),
                        ),
                        contentPadding: EdgeInsets.all(8.0),
                        labelText: 'Pin',
                        hintText: 'Enter your moru pin',
                        suffixIcon: Icon(Icons.arrow_drop_down))),
              ),
              Visibility(
                visible: isUserValidated,
                child: TextFormField(
                    controller: _otpController,
                    decoration: InputDecoration(
                        //errorText: hasInvalidPin ? 'Invalid  Pin' : null,
                        border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(8),
                          borderSide: BorderSide(
                            width: 0.1,
                            color: Colors.transparent,
                            style: BorderStyle.solid,
                          ),
                        ),
                        contentPadding: EdgeInsets.all(8.0),
                        labelText: 'Pin',
                        hintText: 'Enter your moru pin',
                        suffixIcon: Icon(Icons.arrow_drop_down))),
              ),
              Visibility(
                visible: !isUserValidated,
                child: MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: 40,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 55,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () {
                    _userValidatorCubit.validateUser(
                        userValidate: UserValidate(
                            accessKey: widget.accessKey,
                            txnRequestId: widget
                                .validatedAccessRes.data!.moruTxnIdentifier!,
                            pin: _pinController.text,
                            mobileNo: _mobileController.text));
                  },
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "Continue",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
              ),
              Visibility(
                visible: isUserValidated,
                child: MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: 40,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 55,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () {
                    _initiatePayCubit.initiatePay(
                      payData: PayData(
                          accessKey: widget.accessKey,
                          txnRequestId:
                              _validatedUserRes!.data!.moruTxnIdentifier!,
                          otp: _validatedUserRes!.data!.otp!),
                    );
                  },
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "Pay",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
